@@ -10,6 +10,11 @@ use POE::Component::Server::HTTP qw(RC_WAIT);
 
 sub Queues { 'WWW::Selenium::Server::Queue' }
 
+sub _log {
+    return unless $ENV{SELENIUM_SERVER_LOG};
+    print STDERR @_, "\n";
+}
+
 sub driver {
     my( $request, $response ) = @_;
     my %query = $request->uri->query_form;
@@ -18,12 +23,14 @@ sub driver {
     $response->code( RC_WAIT );
 
     if( exists $query{commandResult} ) {
+        _log( 'driver: addResult: ', $query{commandResult} );
         Queues->enqueue_response( $query{commandResult} );
     }
 
     my $cb = sub {
         my $elt = shift;
 
+	_log( 'driver: gotResult: ', $elt );
         $response->content( $elt );
         $response->continue if $response->code == RC_WAIT;
         $response->code( RC_OK );
@@ -31,11 +38,14 @@ sub driver {
     my $runner = $poe_kernel->alias_resolve( 'runner' );
 
     if( exists $query{seleniumStart} || exists $query{commandResult} ) {
+        _log( 'driver: addResult' );
         Queues->dequeue_command( $runner->postback( 'callback', $cb ) );
     } elsif( exists $query{addCommand} ) {
+        _log( 'driver: addCommand: ', $query{addCommand} );
         Queues->enqueue_command( $query{addCommand} );
         $response->code( RC_NO_CONTENT );
     } elsif( exists $query{getResult} ) {
+        _log( 'driver: getResult' );
         Queues->dequeue_response( $runner->postback( 'callback', $cb ) );
     }
 
